@@ -16,12 +16,13 @@ if __name__ == "__main__":
 
     scores = darthvader.news_summary(
         *args,
-        window=2,  # how many days back from up_to to get news from
-        up_to="2021-4-22T00:00:00Z",
     )  # latest date to get news from
+    print("News\n--")
     pprint(scores)
+
     scores = darthvader.twitter_summary(
         *args,
     )  # latest date to get news from
+    print("\nTwitter\n--")
     pprint(scores)
 # """
